%define major		2
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define octlibdir       %(LC_ALL=C octave-config -p OCTLIBDIR)

Name:		pfstools
Version:	2.2.0
Release:	%mkrel 15
Summary:	Programs for handling high-dynamic range images
Group:		Graphics/Utilities
License:	GPLv2+
URL:		https://pfstools.sourceforge.net/
Source0:	https://sourceforge.net/projects/pfstools/files/%{name}/%{version}/%{name}-%{version}.tgz
Patch0:		pfstools-2.1.0-30_parallel_build.patch
# patch derived from https://github.com/pld-linux/pfstools/commit/67bd2304e516545f2b203f975ac5dd30d2b479b3
# I guess it could go upstream as is; sent email to mantiuk at gmail
Patch1:		pfstools-2.0.6-ImageMagick7.patch
#(eatdirt) find glut library
Patch2:		pfstools-freeglut.patch
Patch3:		pfstools-openexr3.patch
#(eatdirt) normalization option (reported upstream)
Patch4:		pfstools-2.2.0-normoptions.patch
Patch5:		pfstools-cmake-4.0.patch
BuildRequires:	cmake
BuildRequires:	texlive
BuildRequires:	netpbm-devel

BuildRequires:	octave-devel
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(gsl)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(ImageMagick)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(xi)
BuildRequires:  pkgconfig(libexif)
#BuildRequires:  pkgconfig(opencv)

Obsoletes:	pfstools-gdal < 1.8.5-3


%description
pfstools is a set of command line programs for reading,
writing, manipulating and viewing high-dynamic range (HDR) images and
video frames. All programs in the package exchange data using unix
pipes and a simple generic HDR image format (pfs). The concept of the
pfstools is similar to netpbm package for low-dynamic range images.


%package -n	pfscalibration
Summary:	Scripts and programs for photometric calibration
Group:		Graphics/Utilities
Requires:	perl
Requires:	dcraw
Requires:	jhead

%description -n	pfscalibration
PFScalibration package provides an implementation of the Robertson et al. 2003
method for the photometric calibration of cameras, Mitsunaga and Nayar's
algorithm "Radiometric Self Calibration", and for the recovery of high dynamic
range (HDR) images from the set of low dynamic range (LDR) exposures.


%package -n	pfstmo
Summary:	PFS tone mapping operators
Group:		Graphics/Utilities

%description -n	pfstmo
The pfstmo package contains the implementation of state-of-the-art tone
mapping operators. The motivation here is to provide an implementation of
tone mapping operators suitable for convenient processing of both static
images and animations.


%package -n	%{libname}
Summary:	Libraries for HDR processing
Group:		System/Libraries
License:	LGPLv2+

%description -n	%{libname}
The %{libname} package contains a runtime library of functions for
handling HDR graphics files.


%package	qt
Summary:	Qt5-based viewer for HDR files
Group:		Graphics/Viewers

%description	qt
The pfstools-qt package contains viewer programs based on qt5 for
viewing HDR graphics files.


%package	glview
Summary:	GL-based viewer for HDR files
Group:		Graphics/Viewers

%description	glview
The pfstools-glview package contains viewer programs based on OpenGL for
viewing HDR graphics files.


%package	exr
Summary:	EXR file import for PFS tools
Group:		Graphics/Utilities

%description	exr
The pfstools-exr package contains input and output filters for EXR files
to and from the HDR graphics file format used in pfstools.


%package	yuy
Summary:	YUY file import for PFS tools
Group:		Graphics/Utilities

%description	yuy
The pfstools-yuy package contains input and output filters for YUY files
to handle uncompressed video used by many video codecs in pfstools.


%package	imgmagick
Summary:	ImageMagick file import for PFS tools
Group:		Graphics/Utilities

%description	imgmagick
The pfstools-imgmagick package contains input and output filters based in
ImageMagick to and from the HDR graphics file format used in pfstools.


%package	octave
Summary:	Octave interaction with PFS tools
Group:		Graphics/Utilities

%description	octave
The pfstools-octave package contains programs to process red, green and blue
channels or luminance channels in pfs stream using Octave.


%package -n	%{develname}
Summary:	Files for development with PFS tools
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains the header files and link libraries,
etc., for developing programs which can handle HDR graphics files.


%prep
%autosetup -p1

%build
#(eatdirt) openCV is off because pfsalign requires nonfree part that
#we do not distribute
export LDFLAGS="%{ldflags} -L%{octlibdir} -loctave -loctinterp"
%cmake \
	-DLIB_DIR=%{_lib} \
        -DWITH_OpenCV=OFF
%cmake_build

%install
%cmake_install

# nuke unpackaged files
find %{buildroot} -name 'pfsinjpeghdr.1' -delete
find %{buildroot} -name 'pfsoutjpeghdr.1' -delete

%files
%doc AUTHORS ChangeLog README doc/faq.txt
%{_bindir}/pfsabsolute
%{_bindir}/pfscat
%{_bindir}/pfsclamp
%{_bindir}/pfscut
%{_bindir}/pfsextractchannels
%{_bindir}/pfsdisplayfunction
%{_bindir}/pfsflip
%{_bindir}/pfsgamma
%{_bindir}/pfsin
%{_bindir}/pfsindcraw
%{_bindir}/pfsinpfm
%{_bindir}/pfsinppm
%{_bindir}/pfsinrgbe
%{_bindir}/pfsintiff
%{_bindir}/pfsout
%{_bindir}/pfsouthdrhtml
%{_bindir}/pfsoutpfm
%{_bindir}/pfsoutppm
%{_bindir}/pfsoutrgbe
%{_bindir}/pfsouttiff
%{_bindir}/pfspad
%{_bindir}/pfspanoramic
%{_bindir}/pfsrotate
%{_bindir}/pfssize
%{_bindir}/pfstag
%{_bindir}/pfscolortransform
%{_bindir}/pfsretime
%{_bindir}/pfs_automerge
%{_bindir}/pfs_split_exposures.py
%{_datadir}/pfstools/hdrhtml_c_b2.csv
%{_datadir}/pfstools/hdrhtml_c_b3.csv
%{_datadir}/pfstools/hdrhtml_c_b4.csv
%{_datadir}/pfstools/hdrhtml_c_b5.csv
%{_datadir}/pfstools/hdrhtml_default_templ/
%{_datadir}/pfstools/hdrhtml_hdrlabs_templ/
%{_datadir}/pfstools/hdrhtml_t_b2.csv
%{_datadir}/pfstools/hdrhtml_t_b3.csv
%{_datadir}/pfstools/hdrhtml_t_b4.csv
%{_datadir}/pfstools/hdrhtml_t_b5.csv
%{_mandir}/man1/pfsabsolute.1*
%{_mandir}/man1/pfscat.1*
%{_mandir}/man1/pfsclamp.1*
%{_mandir}/man1/pfscut.1*
%{_mandir}/man1/pfsdisplayfunction.1*
%{_mandir}/man1/pfsextractchannels.1*
%{_mandir}/man1/pfsflip.1*
%{_mandir}/man1/pfsgamma.1*
%{_mandir}/man1/pfsin.1*
%{_mandir}/man1/pfsindcraw.1*
%{_mandir}/man1/pfsinpfm.1*
%{_mandir}/man1/pfsinppm.1*
%{_mandir}/man1/pfsinrgbe.1*
%{_mandir}/man1/pfsintiff.1*
%{_mandir}/man1/pfsout.1*
%{_mandir}/man1/pfsouthdrhtml.1*
%{_mandir}/man1/pfsoutpfm.1*
%{_mandir}/man1/pfsoutppm.1*
%{_mandir}/man1/pfsoutrgbe.1*
%{_mandir}/man1/pfsouttiff.1*
%{_mandir}/man1/pfspad.1*
%{_mandir}/man1/pfspanoramic.1*
%{_mandir}/man1/pfsrotate.1*
%{_mandir}/man1/pfssize.1*
%{_mandir}/man1/pfstag.1*
%{_mandir}/man1/pfscolortransform.1*
%{_mandir}/man1/pfsretime.1*
%{_mandir}/man1/pfs_automerge.1*

%files -n pfscalibration
%{_bindir}/dcraw2hdrgen
%{_bindir}/jpeg2hdrgen
%{_bindir}/pfshdrcalibrate
%{_bindir}/pfsinhdrgen
%{_bindir}/pfsinme
%{_bindir}/pfsplotresponse
%{_mandir}/man1/dcraw2hdrgen.1*
%{_mandir}/man1/jpeg2hdrgen.1*
%{_mandir}/man1/pfshdrcalibrate.1*
%{_mandir}/man1/pfsinhdrgen.1*
%{_mandir}/man1/pfsinme.1*
%{_mandir}/man1/pfsplotresponse.1*

%files -n pfstmo
%{_bindir}/pfstmo_reinhard05
%{_bindir}/pfstmo_pattanaik00
%{_bindir}/pfstmo_mantiuk06
%{_bindir}/pfstmo_fattal02
%{_bindir}/pfstmo_drago03
%{_bindir}/pfstmo_reinhard02
%{_bindir}/pfstmo_durand02
%{_bindir}/pfstmo_mantiuk08
%{_bindir}/pfstmo_ferradans11
%{_bindir}/pfstmo_mai11
%{_mandir}/man1/pfstmo_reinhard05.1*
%{_mandir}/man1/pfstmo_pattanaik00.1*
%{_mandir}/man1/pfstmo_mantiuk06.1*
%{_mandir}/man1/pfstmo_fattal02.1*
%{_mandir}/man1/pfstmo_drago03.1*
%{_mandir}/man1/pfstmo_reinhard02.1*
%{_mandir}/man1/pfstmo_durand02.1*
%{_mandir}/man1/pfstmo_mantiuk08.1*
%{_mandir}/man1/pfstmo_ferradans11.1*
%{_mandir}/man1/pfstmo_mai11.1*

%files -n %{libname}
%{_libdir}/libpfs.so.%{major}
%{_libdir}/libpfs.so.%{major}.*

%files qt
%{_bindir}/pfsv
%{_bindir}/pfsview
%{_mandir}/man1/pfsview.1*

%files glview
%{_bindir}/pfsglview
%{_mandir}/man1/pfsglview.1*

%files exr
%{_bindir}/pfsinexr
%{_bindir}/pfsoutexr
%{_mandir}/man1/pfsinexr.1*
%{_mandir}/man1/pfsoutexr.1*

%files yuy
%{_bindir}/pfsinyuv
%{_bindir}/pfsoutyuv
%{_mandir}/man1/pfsinyuv.1*
%{_mandir}/man1/pfsoutyuv.1*

%files imgmagick
%{_bindir}/pfsinimgmagick
%{_bindir}/pfsoutimgmagick
%{_mandir}/man1/pfsinimgmagick.1*
%{_mandir}/man1/pfsoutimgmagick.1*

%files octave
%{_bindir}/pfsoctavelum
%{_bindir}/pfsoctavergb
%{_bindir}/pfsstat
%{_libdir}/octave/*/site/oct/*/pfstools
%{_datadir}/octave/*/site/m/pfstools
%{_mandir}/man1/pfsoctavelum.1*
%{_mandir}/man1/pfsoctavergb.1*
%{_mandir}/man1/pfsstat.1*

%files -n %{develname}
%doc doc/pfs_format_spec.tex
%{_libdir}/libpfs.so
%{_libdir}/pkgconfig/pfs.pc
%{_includedir}/pfs


%changelog
* Tue Jul 01 2025 daviddavid <daviddavid> 2.2.0-15.mga10
+ Revision: 2233486
- fix build with cmake 4.0
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Tue Mar 19 2024 daviddavid <daviddavid> 2.2.0-14.1.mga10
+ Revision: 2050784
- rebuild for new octave 9.1.0

* Thu Nov 30 2023 eatdirt <eatdirt> 2.2.0-12.mga10
+ Revision: 2011845
+ rebuild (emptylog)

* Wed Nov 29 2023 eatdirt <eatdirt> 2.2.0-11.mga10
+ Revision: 2011491
+ rebuild (emptylog)

* Wed Nov 29 2023 eatdirt <eatdirt> 2.2.0-10.mga10
+ Revision: 2011218
- Add normalization option to hdr calibration

* Wed Mar 22 2023 daviddavid <daviddavid> 2.2.0-8.mga9
+ Revision: 1950026
- rebuild for new octave

* Thu Dec 29 2022 daviddavid <daviddavid> 2.2.0-7.mga9
+ Revision: 1927528
- rebuild for new gsl 2.7.1

* Mon Dec 12 2022 ns80 <ns80> 2.2.0-6.mga9
+ Revision: 1921097
- rebuild for new libtiff

* Fri Nov 25 2022 daviddavid <daviddavid> 2.2.0-5.mga9
+ Revision: 1910960
- add fedora patch to fix build

* Fri Jun 24 2022 papoteur <papoteur> 2.2.0-4.mga9
+ Revision: 1865842
- Mass Rebuild for dependencies

* Wed Apr 06 2022 umeabot <umeabot> 2.2.0-3.mga9
+ Revision: 1846044
- Mageia 9 Mass Rebuild

* Sun Dec 26 2021 wally <wally> 2.2.0-2.mga9
+ Revision: 1764110
- rebuild for openexr 3.1.3

* Mon Dec 13 2021 eatdirt <eatdirt> 2.2.0-1.mga9
+ Revision: 1762012
- Update to bug fix release 2.2.0

* Sat Feb 27 2021 neoclust <neoclust> 2.1.0-21.mga9
+ Revision: 1692878
- Rebuild against new imagemagick

* Thu Dec 24 2020 eatdirt <eatdirt> 2.1.0-20.mga8
+ Revision: 1663487
- Fix build against new octave
- Rebuild for new octave

* Thu Dec 17 2020 umeabot <umeabot> 2.1.0-18.mga8
+ Revision: 1659293
- Rebuild for new Qt5

* Sat Sep 26 2020 tv <tv> 2.1.0-17.mga8
+ Revision: 1630183
- rebuild for new libIlmImf
+ danf <danf>
- Switch URLs from http: to https:

* Tue Feb 18 2020 umeabot <umeabot> 2.1.0-16.mga8
+ Revision: 1541581
- Mageia 8 Mass Rebuild

* Mon Dec 30 2019 kekepower <kekepower> 2.1.0-15.mga8
+ Revision: 1474951
- Rebuild for new imagemagick
+ wally <wally>
- build with new cmake macros

* Tue Aug 27 2019 daviddavid <daviddavid> 2.1.0-14.mga8
+ Revision: 1433767
- rebuild for new gsl 2.6

* Sun Mar 31 2019 umeabot <umeabot> 2.1.0-13.mga7
+ Revision: 1383879
- Qt5 Rebuild

* Tue Mar 05 2019 eatdirt <eatdirt> 2.1.0-12.mga7
+ Revision: 1371711
- Fix fmt security and link against new octave
- Rebuild for new octave

* Tue Jan 29 2019 daviddavid <daviddavid> 2.1.0-11.mga7
+ Revision: 1361843
- octave build requires libpfs, add CMake dependency
- drop no more needed gcc44 patch

* Mon Oct 15 2018 daviddavid <daviddavid> 2.1.0-10.mga7
+ Revision: 1320595
- rebuild for new ilmbase and openexr 2.3.0
- rebuild for new octave 4.4.1

* Sun Sep 23 2018 umeabot <umeabot> 2.1.0-9.mga7
+ Revision: 1300195
- Mageia 7 Mass Rebuild

* Sun May 27 2018 wally <wally> 2.1.0-8.mga7
+ Revision: 1232429
- rebuild for openexr 2.2.1

* Mon May 14 2018 daviddavid <daviddavid> 2.1.0-7.mga7
+ Revision: 1229290
- rebuild for new octave 4.4.0

* Wed May 02 2018 kekepower <kekepower> 2.1.0-6.mga7
+ Revision: 1224490
- Rebuild for ImageMagic 7.0.7.29

* Sun Jan 21 2018 daviddavid <daviddavid> 2.1.0-5.mga7
+ Revision: 1195414
- add patch from opensuse to fix build with new imagemagick-7
- rebuild for new imagemagick

* Sat Jan 13 2018 wally <wally> 2.1.0-4.mga7
+ Revision: 1192568
- rebuild for new ilmbase

* Wed Dec 27 2017 wally <wally> 2.1.0-3.mga7
+ Revision: 1185812
- rebuild for new imagemagick

* Sat Dec 23 2017 daviddavid <daviddavid> 2.1.0-1.mga7
+ Revision: 1184219
- new version: 2.1.0

* Sun May 28 2017 shlomif <shlomif> 2.0.6-3.mga6
+ Revision: 1105289
- rebuild / resubmit
- rebuild for new imagemagick lib major

* Wed Apr 26 2017 akien <akien> 2.0.6-1.mga6
+ Revision: 1097537
- Version 2.0.6

* Fri Dec 02 2016 eatdirt <eatdirt> 2.0.5-2.mga6
+ Revision: 1071792
- Rebuild for new octave

* Thu May 26 2016 daviddavid <daviddavid> 2.0.5-1.mga6
+ Revision: 1018850
- new version: 2.0.5
- remove merged upstream patches

* Tue Jan 26 2016 luigiwalser <luigiwalser> 2.0.4-7.mga6
+ Revision: 927868
- rebuild for gsl

* Mon Jan 11 2016 neoclust <neoclust> 2.0.4-6.mga6
+ Revision: 921462
- Fix BuildRequires

* Tue Nov 10 2015 daviddavid <daviddavid> 2.0.4-5.mga6
+ Revision: 900746
- rebuild for new octave 4.0.0

* Thu Oct 29 2015 tv <tv> 2.0.4-4.mga6
+ Revision: 896235
- BR pkgconfig(pfs)

* Fri Aug 28 2015 cjw <cjw> 2.0.4-3.mga6
+ Revision: 870404
- rebuild with gcc 5

* Fri Jul 24 2015 daviddavid <daviddavid> 2.0.4-2.mga6
+ Revision: 856988
- remove unneeded requires (as there are auto-required)

* Fri Jul 24 2015 daviddavid <daviddavid> 2.0.4-1.mga6
+ Revision: 856842
- new version: 2.0.4
- switch to cmake build
- now major is 2
- remove no more needed Patches
- add 3 Patches from Fedora
- add more BuildRequires on gsl and fftw3
- update Source URL
- obsoletes pfstools-gdal subpackage (removed upstream)
- pfscalibration and pfstmo are now part of pfstools
- update file list

* Tue Jun 23 2015 daviddavid <daviddavid> 1.8.5-2.mga6
+ Revision: 841454
- rebuild for new ImageMagick

* Tue Jan 27 2015 daviddavid <daviddavid> 1.8.5-1.mga5
+ Revision: 812448
- imported package pfstools
- based from Fedora's package
- adapt for Mageia

